@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2010, 2011 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2010, 2011, 2013 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,11 +21,11 @@
 #define FILTER_MODEL_H
 
 #include <QSortFilterProxyModel>
-class DataModel;
+class SessionModel;
 
 class FilterModel : public QSortFilterProxyModel {
 public:
-	FilterModel(DataModel* model, QObject* parent = 0);
+	FilterModel(SessionModel* model, QObject* parent = 0);
 
 	QModelIndex mapUnbilledToSource(const QModelIndex& proxy_index) const;
 
@@ -47,7 +47,7 @@ protected:
 	bool filterAcceptsRow(int row, const QModelIndex& parent) const;
 
 private:
-	DataModel* m_model;
+	SessionModel* m_model;
 	int m_type;
 };
 
