@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009, 2011, 2012 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2011, 2012, 2013, 2014, 2016 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,17 +20,12 @@
 #include "report.h"
 
 #include "contact.h"
-#include "data_model.h"
 #include "rates.h"
 #include "settings.h"
+#include "session_model.h"
 
 #include <QCheckBox>
 #include <QComboBox>
-#if (QT_VERSION >= QT_VERSION_CHECK(5,0,0))
-#include <QStandardPaths>
-#else
-#include <QDesktopServices>
-#endif
 #include <QDialogButtonBox>
 #include <QDoubleSpinBox>
 #include <QFileDialog>
@@ -42,6 +37,7 @@
 #include <QPrintDialog>
 #include <QPrinter>
 #include <QPushButton>
+#include <QStandardPaths>
 #include <QTabWidget>
 #include <QTextEdit>
 #include <QTextStream>
@@ -50,7 +46,7 @@
 
 /*****************************************************************************/
 
-Report::Report(DataModel* data, int current, Contact* contact, Rates* rates, QWidget* parent) :
+Report::Report(SessionModel* data, int current, Contact* contact, Rates* rates, QWidget* parent) :
 	QDialog(parent), m_data(data), m_current_row(current), m_contact(contact), m_rates(rates)
 {
 	// Create contact information widgets
@@ -92,22 +88,12 @@ Report::Report(DataModel* data, int current, Contact* contact, Rates* rates, QWi
 	m_details->setSelectionMode(QAbstractItemView::SingleSelection);
 	m_details->setSelectionBehavior(QAbstractItemView::SelectRows);
 	m_details->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
-#if (QT_VERSION >= QT_VERSION_CHECK(5,0,0))
 	m_details->header()->setSectionsClickable(false);
 	m_details->header()->setSectionsMovable(false);
 	m_details->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
-#else
-	m_details->header()->setClickable(false);
-	m_details->header()->setMovable(false);
-	m_details->header()->setResizeMode(QHeaderView::ResizeToContents);
-#endif
 
 	m_details->setModel(m_data);
-#if (QT_VERSION >= QT_VERSION_CHECK(5,0,0))
 	m_details->header()->setSectionResizeMode(3, QHeaderView::Stretch);
-#else
-	m_details->header()->setResizeMode(3, QHeaderView::Stretch);
-#endif
 	m_details->header()->setStretchLastSection(false);
 	for (int i = 5; i < 10; ++i) {
 		m_details->setColumnHidden(i, true);
@@ -240,7 +226,7 @@ void Report::groupSelected(int group) {
 	}
 
 	QList<QVariant> rows = m_groups->itemData(group).toList();
-	foreach (const QVariant& row, rows) {
+	for (const QVariant& row : rows) {
 		m_details->setRowHidden(row.toInt(), QModelIndex(), false);
 	}
 
@@ -294,11 +280,7 @@ void Report::save() {
 	QString selected_filter;
 	QString filename = QFileDialog::getSaveFileName(this,
 		tr("Export Report"),
-#if (QT_VERSION >= QT_VERSION_CHECK(5,0,0))
 		QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation),
-#else
-		QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation),
-#endif
 		filter,
 		&selected_filter);
 	if (!filename.isEmpty()) {
@@ -461,7 +443,7 @@ QString Report::generateHtml() const {
 
 	// Add billing information
 	QString hours = m_data->session(last).total(Session::Total, true);
-	double value = hours.toDouble();
+	double value = QLocale().toDouble(hours);
 	html += "<tr><td colspan=\"4\"></td><td colspan=\"2\"><hr></td>\n";
 	html += "<tr><td colspan=\"4\"></td><td>" + tr("Hours") + "</td><td align=\"right\">" + hours + "</td></tr>\n";
 	double hourly_rate = m_hourly_rate->value();
@@ -547,11 +529,7 @@ void Report::writeICalendar(QString filename) {
 				continue;
 			}
 
-#if (QT_VERSION >= QT_VERSION_CHECK(4,7,0))
 			QString now = QDateTime::currentDateTimeUtc().toString("yyyyMMddThhmmssZ");
-#else
-			QString now = QDateTime::currentDateTime().toUTC().toString("yyyyMMddThhmmssZ");
-#endif
 			if (current == now) {
 				dup++;
 			} else {
